Summary:   An archiving tool with ACL support
Name:      star
Version:   1.6
Release:   4%{?dist}
License:   CDDL
URL:       https://sourceforge.net/projects/s-tar/
Source:    https://downloads.sourceforge.net/s-tar/%{name}-%{version}.tar.bz2

# Bugfix for all.mk broken
Patch3000: star-1.6-star-mk.patch

# Bugfix for buffer overflow when filenames is over 100 characters (#556664)
Patch3001: star-1.5.2-bufferoverflow.patch

# Bugfix for some invalid manpage references (#624612)
Patch3002: star-1.6-manpagereferences.patch

# Rmt is allowed to access all files
Patch3003: star-1.5.2-rmt-rh-access.patch

# Use ssh rather than rsh by default
Patch3004: star-1.5.2-use-ssh-by-default.patch

BuildRequires: make libtool
BuildRequires: libattr-devel libacl-devel libselinux-devel e2fsprogs-devel

%description
Star is a unique standard tape archiver, it saves many files together
into a single tape or disk archive,and can restore individual files
from the archive. Star supports ACL.

%package -n     spax
Summary:        Portable archive exchange
Requires(post):  chkconfig
Requires(preun): chkconfig


%description -n spax
This package is a pax utility which shall read and write archives, write
lists of the members of archive files and copy directory hierarchies
as is defined in IEEE Std 1003.1.

%package -n     scpio
Summary:        Copy file archives in and out (LEGACY)

%description -n scpio
This package is a scpio utility which depending on the options used:
copies files to an archive file, extracts files from an archive file,
lists files from an archive file or copies files from one directory
tree to another.

%package -n     rmt
Summary: Provides certain programs with access to remote tape devices

%description -n rmt
This package is a rmt utility which provides remote access to tape
devices for programs like dump (a filesystem backup program),
restore (a program for restoring files from a backup),
and tar (an archiving program).

%prep
%autosetup -n %{name}-%{version} -p1

cp -a star/all.mk star/Makefile

for PLAT in ppc64le aarch64 x86_64; do
    for AFILE in gcc cc; do
            [ ! -e RULES/${PLAT}-linux-${AFILE}.rul ] \
            && ln -s i586-linux-${AFILE}.rul RULES/${PLAT}-linux-${AFILE}.rul
    done
done

%build
%global make_flags GMAKE_NOWARN=true                                    \\\
    RUNPATH=                                                            \\\
    LDPATH=                                                             \\\
    PARCH=%{_target_cpu}                                                \\\
    K_ARCH=%{_target_cpu}                                               \\\
    INS_BASE=$RPM_BUILD_ROOT%{_prefix}                                  \\\
    INS_RBASE=$RPM_BUILD_ROOT                                           \\\
    INSTALL='sh $(SRCROOT)/conf/install-sh -c -m $(INSMODEINS)'         \\\
    COPTX="$RPM_OPT_FLAGS -DTRY_EXT2_FS"                                \\\
    LDOPTX="$RPM_LD_FLAGS"                                              \\\
    DEFCCOM=gcc

make %{?_smp_mflags} %make_flags

%install
make install -s %make_flags

ln -s star.1.gz %{buildroot}%{_mandir}/man1/ustar.1
mkdir -p %{buildroot}%{_sysconfdir}
mkdir -p %{buildroot}%{_pkgdocdir}
ln -s %{_sbindir}/rmt %{buildroot}%{_sysconfdir}/rmt
install -p -m 644 COPYING star/README  CDDL.Schily.txt AN-* \
    %{buildroot}%{_pkgdocdir}

( cd %{buildroot}
  rm -f .%{_bindir}/mt
  rm -f .%{_bindir}/smt
  rm -f .%{_bindir}/tartest
  rm -f .%{_bindir}/tar
  rm -f .%{_bindir}/gnutar
  rm -f .%{_bindir}/star_fat
  rm -f .%{_bindir}/star_sym
  rm -f .%{_bindir}/suntar
  rm -f .%{_sysconfdir}/default/star
  rm -rf .%{_prefix}%{_sysconfdir}
  rm -rf .%{_prefix}/include
  rm -rf .%{_prefix}/lib
  rm -rf .%{_mandir}/man3
  rm -rf .%{_mandir}/man5/{makefiles,makerules}.5*
  rm -rf .%{_mandir}/man1/{tartest,gnutar,smt,mt,suntar,match}.1*
  rm -rf .%{_docdir}/star/testscripts
  rm -rf .%{_docdir}/star/TODO
  rm -rf .%{_docdir}/rmt
)

%post -n spax
%{_sbindir}/alternatives \
    --install   %{_bindir}/pax     pax     %{_bindir}/spax     66 \
    --slave     %{_mandir}/man1/pax.1.gz pax-man %{_mandir}/man1/spax.1.gz

%preun -n spax
if [ $1 -eq 0 ]; then
    %{_sbindir}/alternatives --remove pax %{_bindir}/spax
fi

%files
%doc %{_pkgdocdir}
%{_bindir}/star
%{_bindir}/ustar
%{_mandir}/man1/star.1*
%{_mandir}/man1/star_sym.1*
%{_mandir}/man1/ustar.1*
%{_mandir}/man5/star.5*

%files -n scpio
%dir %{_pkgdocdir}
%doc %{_pkgdocdir}/COPYING
%doc %{_pkgdocdir}/CDDL.Schily.txt
%{_bindir}/scpio
%doc %{_mandir}/man1/scpio.1*

%files -n spax
%dir %{_pkgdocdir}
%doc %{_pkgdocdir}/COPYING
%doc %{_pkgdocdir}/CDDL.Schily.txt
%{_bindir}/spax
%ghost %verify(not md5 size mode mtime) %{_bindir}/pax
%doc %{_mandir}/man1/spax.1*
%ghost %verify(not md5 size mode mtime) %{_mandir}/man1/pax.1.gz

%files -n rmt
%dir %{_pkgdocdir}
%doc %{_pkgdocdir}/COPYING
%doc %{_pkgdocdir}/CDDL.Schily.txt
%config %{_sysconfdir}/default/rmt
%{_sysconfdir}/rmt
%{_sbindir}/rmt
%{_mandir}/man1/rmt.1*

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.6-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.6-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.6-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Sep 5 2022 Shuo Wang <abushwang@tencent.com> - 1.6-1
- initial build
